@@ -1,26 +1,9 @@
-/* This file is part of Zanshin
-
-   Copyright 2014 Kevin Ottens <ervin@kde.org>
-
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 2 of
-   the License or (at your option) version 3 or any later version
-   accepted by the membership of KDE e.V. (or its successor approved
-   by the membership of KDE e.V.), which shall act as a proxy
-   defined in Section 14 of version 3 of the license.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
-   USA.
+/*
+ * SPDX-FileCopyrightText: 2014 Kevin Ottens <ervin@kde.org>
+ SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
+
 #include <testlib/qtest_gui_zanshin.h>
 
 #include <QAbstractItemModel>
@@ -199,6 +182,10 @@ private slots:
         QVERIFY(filterAction);
         QVERIFY(filterAction->isCheckable());
         QVERIFY(!filterAction->isChecked());
+	auto doneAction = page.findChild<QAction*>(QStringLiteral("doneViewAction"));
+        QVERIFY(doneAction);
+        QVERIFY(doneAction->isCheckable());
+        QVERIFY(doneAction->isChecked());
         auto futureAction = page.findChild<QAction*>(QStringLiteral("futureViewAction"));
         QVERIFY(futureAction);
         QVERIFY(futureAction->isCheckable());
@@ -212,6 +199,7 @@ private slots:
         QCOMPARE(actions.value(QStringLiteral("page_view_remove")), removeAction);
         QCOMPARE(actions.value(QStringLiteral("page_view_promote")), promoteAction);
         QCOMPARE(actions.value(QStringLiteral("page_view_filter")), filterAction);
+	QCOMPARE(actions.value(QStringLiteral("page_view_done")), doneAction);
         QCOMPARE(actions.value(QStringLiteral("page_view_future")), futureAction);
         QCOMPARE(actions.value(QStringLiteral("page_run_task")), runTaskAction);
     }
@@ -275,7 +263,8 @@ private slots:
         auto filterEdit = filter->findChild<QLineEdit*>();
         QVERIFY(filterEdit);
         page.show();
-        QVERIFY(QTest::qWaitForWindowExposed(&page));
+        page.activateWindow();
+        QVERIFY(QTest::qWaitForWindowActive(&page));
 
         centralView->setFocus();
         QVERIFY(centralView->hasFocus());
@@ -333,7 +322,8 @@ private slots:
         auto filterEdit = filter->findChild<QLineEdit*>();
         QVERIFY(filterEdit);
         page.show();
-        QVERIFY(QTest::qWaitForWindowExposed(&page));
+        page.activateWindow();
+        QVERIFY(QTest::qWaitForWindowActive(&page));
 
         centralView->setFocus();
         QVERIFY(centralView->hasFocus());
@@ -366,6 +356,94 @@ private slots:
         QVERIFY(filterEdit->text().isEmpty());
     }
 
+    void shouldManageDoneTasksVisibilityThroughAction()
+    {
+        // GIVEN
+        Widgets::PageView page;
+        auto filter = page.findChild<Widgets::FilterWidget*>(QStringLiteral("filterWidget"));
+        auto filterProxy = filter->proxyModel();
+        QVERIFY(filterProxy);
+
+        QVERIFY(filterProxy->showDoneTasks());
+
+        auto doneAction = page.findChild<QAction*>(QStringLiteral("doneViewAction"));
+
+        // WHEN
+        doneAction->trigger();
+
+        // THEN
+        QVERIFY(!filterProxy->showDoneTasks());
+
+        // WHEN
+        doneAction->trigger();
+
+        // THEN
+        QVERIFY(filterProxy->showDoneTasks());
+    }
+
+    void shouldStoreDoneTasksVisibilityDefaultState()
+    {
+        // GIVEN
+        configGroup().deleteEntry("ShowDone");
+
+        {
+            Widgets::PageView page;
+            auto doneAction = page.findChild<QAction*>(QStringLiteral("doneViewAction"));
+
+            // THEN
+            QVERIFY(doneAction->isChecked());
+        }
+
+        // WHEN
+        configGroup().writeEntry("ShowDone", false);
+
+        {
+            Widgets::PageView page;
+            auto doneAction = page.findChild<QAction*>(QStringLiteral("doneViewAction"));
+
+            // THEN
+            QVERIFY(!doneAction->isChecked());
+        }
+
+        // WHEN
+        configGroup().writeEntry("ShowDone", true);
+
+        {
+            Widgets::PageView page;
+            auto doneAction = page.findChild<QAction*>(QStringLiteral("doneViewAction"));
+
+            // THEN
+            QVERIFY(doneAction->isChecked());
+        }
+
+        // WHEN
+        configGroup().deleteEntry("ShowDone");
+
+        {
+            Widgets::PageView page;
+            auto doneAction = page.findChild<QAction*>(QStringLiteral("doneViewAction"));
+
+            // THEN
+            QVERIFY(doneAction->isChecked());
+        }
+
+        // WHEN
+        Widgets::PageView page;
+        auto doneAction = page.findChild<QAction*>(QStringLiteral("doneViewAction"));
+        doneAction->trigger();
+
+        // THEN
+        QVERIFY(configGroup().hasKey("ShowDone"));
+        QVERIFY(!configGroup().readEntry("ShowDone", true));
+
+        // WHEN
+        doneAction->trigger();
+
+        // THEN
+        QVERIFY(configGroup().hasKey("ShowDone"));
+        QVERIFY(configGroup().readEntry("ShowDone", false));
+    }
+
     void shouldManageFutureTasksVisibilityThroughAction()
     {
         // GIVEN
@@ -555,8 +633,8 @@ private slots:
 
         // Needed for shortcuts to work
         page.show();
-        QVERIFY(QTest::qWaitForWindowExposed(&page));
-        QTest::qWait(100);
+        page.activateWindow();
+        QVERIFY(QTest::qWaitForWindowActive(&page));
 
         // WHEN
         QTest::keyPress(centralView, Qt::Key_Delete);
@@ -582,8 +660,8 @@ private slots:
 
         // Needed for shortcuts to work
         page.show();
-        QVERIFY(QTest::qWaitForWindowExposed(&page));
-        QTest::qWait(100);
+        page.activateWindow();
+        QVERIFY(QTest::qWaitForWindowActive(&page));
 
         // WHEN
         QTest::keyPress(centralView, Qt::Key_Delete);
@@ -614,8 +692,8 @@ private slots:
 
         // Needed for shortcuts to work
         page.show();
-        QVERIFY(QTest::qWaitForWindowExposed(&page));
-        QTest::qWait(100);
+        page.activateWindow();
+        QVERIFY(QTest::qWaitForWindowActive(&page));
 
         // WHEN
         QTest::keyPress(centralView, Qt::Key_Delete);
@@ -637,7 +715,7 @@ private slots:
 
         QSortFilterProxyModel proxyModel;
         stubPageModel.setProxyModel(&proxyModel);
-        proxyModel.setFilterFixedString("B");
+        proxyModel.setFilterRegularExpression(QStringLiteral("B"));
 
         QPersistentModelIndex index = stubPageModel.centralListModel()->index(0, 0);
         QCOMPARE(index.data().toString(), QLatin1String("B"));
@@ -653,8 +731,8 @@ private slots:
 
         // Needed for shortcuts to work
         page.show();
-        QVERIFY(QTest::qWaitForWindowExposed(&page));
-        QTest::qWait(100);
+        page.activateWindow();
+        QVERIFY(QTest::qWaitForWindowActive(&page));
 
         // WHEN
         QTest::keyPress(centralView, Qt::Key_Delete);
@@ -686,8 +764,8 @@ private slots:
 
         // Needed for shortcuts to work
         page.show();
-        QVERIFY(QTest::qWaitForWindowExposed(&page));
-        QTest::qWait(100);
+        page.activateWindow();
+        QVERIFY(QTest::qWaitForWindowActive(&page));
 
         // WHEN
         QTest::keyPress(centralView, Qt::Key_Delete);
